@@ -76,6 +76,9 @@ pub struct LineInfo {
     pub snr: TxRx<f64>,
     pub speed: TxRx<u32>,
     pub ses: u64,
+    pub es: Option<u64>,
+    pub fec: Option<u64>,
+    pub crc: Option<u64>,
     pub uptime: u64,
     pub inp: u16,
     pub attenuation: TxRx<f64>,
